@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,9 @@
 #include "importmailpluginmanager.h"
 #include "abstractimporter.h"
 #include "importwizard_debug.h"
-#include "kcoreaddons_version.h"
 #include <KPluginFactory>
 #include <KPluginMetaData>
+#include <kcoreaddons_version.h>
 
 #include <QFileInfo>
 
@@ -27,9 +27,7 @@ ImportMailPluginManager::ImportMailPluginManager(QObject *parent)
     initializePluginList();
 }
 
-ImportMailPluginManager::~ImportMailPluginManager()
-{
-}
+ImportMailPluginManager::~ImportMailPluginManager() = default;
 
 ImportMailPluginManager *ImportMailPluginManager::self()
 {
@@ -40,7 +38,11 @@ ImportMailPluginManager *ImportMailPluginManager::self()
 bool ImportMailPluginManager::initializePluginList()
 {
     const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("importwizard"));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QVectorIterator<KPluginMetaData> i(plugins);
+#else
+    QListIterator<KPluginMetaData> i(plugins);
+#endif
     i.toBack();
     while (i.hasPrevious()) {
         ImportMailPluginManagerInfo info;
